match_filter.tribe.Tribe
========================

See notes and warnings on correlations here: correlation_warnings_

.. _correlation_warnings: utils.correlate.html#notes-on-accuracy

.. currentmodule:: eqcorrscan.core.match_filter.tribe

.. autoclass:: Tribe

   .. rubric:: Methods

   .. autosummary::

      client_detect
      cluster
      construct
      copy
      detect
      read
      remove
      sort
      write

   .. automethod:: __init__
   .. automethod:: client_detect
   .. automethod:: cluster
   .. automethod:: construct
   .. automethod:: copy
   .. automethod:: detect
   .. automethod:: read
   .. automethod:: remove
   .. automethod:: sort
   .. automethod:: write

